@@ -17,7 +17,7 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #ifndef linux
-#include <dev/disk.h>
+#include <sys/disk.h>
 #endif
 #include <fcntl.h>
 #include <sys/errno.h>
@@ -184,8 +184,8 @@ ufslabel_read_blocks(int fd, off_t * offset_p, ssize_t * size_p,
     *label_p = NULL;
 
 #ifndef linux
-    if (ioctl(fd, DKIOCBLKSIZE, &blocksize) < 0) {
-	fprintf(stderr, "DKIOCBLKSIZE failed, %s\n", strerror(errno));
+    if (ioctl(fd, DKIOCGETBLOCKSIZE, &blocksize) < 0) {
+	fprintf(stderr, "DKIOCGETBLOCKSIZE failed, %s\n", strerror(errno));
 	return (NULL);
     }
 #else
@@ -420,7 +420,7 @@ static void SHA1Init(SHA1_CTX* context)
 
 static void SHA1Update(SHA1_CTX* context, void* data, size_t len)
 {
-	unsigned char *dataptr = (char *)data;
+	unsigned char *dataptr = data;
 	unsigned int i, j;
 
     j = (context->count[0] >> 3) & 63;
@@ -498,7 +498,7 @@ void GenerateVolumeUUID(VolumeUUID *newVolumeID) {
 	int sysdata;
 	char sysctlstring[128];
 	size_t datalen;
-	struct loadavg sysloadavg;
+	double sysloadavg[3];
 	struct vmtotal sysvmtotal;
 	
 	do {
@@ -547,10 +547,8 @@ void GenerateVolumeUUID(VolumeUUID *newVolumeID) {
 		SHA1Update(&context, sysctlstring, datalen);
 
 		/* The system's load average: */
-		mib[0] = CTL_VM;
-		mib[1] = VM_LOADAVG;
 		datalen = sizeof(sysloadavg);
-		sysctl(mib, 2, &sysloadavg, &datalen, NULL, 0);
+		getloadavg(sysloadavg, 3);
 		SHA1Update(&context, &sysloadavg, datalen);
 
 		/* The system's VM statistics: */
@@ -631,9 +629,15 @@ ufslabel_get_name(struct ufslabel * ul_p, char * name, int * len)
 void
 ufslabel_get_uuid(struct ufslabel * ul_p, char * uuid)
 {
-    VolumeUUID *volumeUUIDptr;
-    volumeUUIDptr = (VolumeUUID *) &ul_p->ul_uuid;
-    ConvertVolumeUUIDToString(volumeUUIDptr, uuid);
+    u_int32_t *volumeUUID;
+    VolumeUUID swappedUUID;
+    
+    volumeUUID = (u_int32_t *) &ul_p->ul_uuid;
+	
+    swappedUUID.v.high = ntohl(volumeUUID[0]);
+    swappedUUID.v.low = ntohl(volumeUUID[1]);
+
+    ConvertVolumeUUIDToString(&swappedUUID, uuid);
 }
 
 boolean_t
@@ -652,9 +656,15 @@ ufslabel_set_name(struct ufslabel * ul_p, char * name, int len)
 void
 ufslabel_set_uuid(struct ufslabel * ul_p)
 {
+    u_int32_t *volumeUUID;
     VolumeUUID newUUID;
+
     GenerateVolumeUUID(&newUUID);
-    bcopy(&newUUID, &ul_p->ul_uuid, sizeof(newUUID));
+    
+    volumeUUID = (u_int32_t *) &ul_p->ul_uuid;
+
+    volumeUUID[0] = htonl(newUUID.v.high);
+    volumeUUID[1] = htonl(newUUID.v.low);
 }
 
 void
